==> ejc-proother-api-3.0.0-20220319.082448-6-sources.jar: com/ejianc/business/proother/vo/ChangeClauseVO.java <==
package com.ejianc.business.proother.vo;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;

/**
 * 分包变更条款
 * 
 * @author generator
 * 
 */
public class ChangeClauseVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    /**
     * 合同条款名称Id
     */
    private Long clauseNameId;

    /**
     * 合同条款名称
     */
    private String clauseName;

    /**
     * 合同条款内容
     */
    private String clauseContent;


    /**
     * 变更主键
     */
    private Long changeId;


    /**
     * 来源子表主键
     */
    private Long srcTblId;

    /**
     * 合同ID
     */
    private Long contractId;

    /**
     * 对比清单使用字段——原合同条款内容
     *
     */
    private String beforeClauseContent;

    /**
     * 对比清单使用字段——原合同条款名称
     *
     */
    private String beforeClauseName;

    /**
     * 对比清单使用字段——变更类型：0-新增项，1-删除项，2-条款内容便更
     */
    private Integer changeType;

    public Integer getChangeType() {
        return changeType;
    }

    public void setChangeType(Integer changeType) {
        this.changeType = changeType;
    }

    public Long getClauseNameId() {
        return clauseNameId;
    }

    @ReferDeserialTransfer
    public void setClauseNameId(Long clauseNameId) {
        this.clauseNameId = clauseNameId;
    }

    public String getClauseName() {
        return clauseName;
    }

    public void setClauseName(String clauseName) {
        this.clauseName = clauseName;
    }

    public String getClauseContent() {
        return clauseContent;
    }

    public void setClauseContent(String clauseContent) {
        this.clauseContent = clauseContent;
    }



    public Long getChangeId() {
        return changeId;
    }

    public void setChangeId(Long changeId) {
        this.changeId = changeId;
    }



    public Long getSrcTblId() {
        return srcTblId;
    }

    public void setSrcTblId(Long srcTblId) {
        this.srcTblId = srcTblId;
    }

    public Long getContractId() {
        return contractId;
    }

    public void setContractId(Long contractId) {
        this.contractId = contractId;
    }

    public String getBeforeClauseContent() {
        return beforeClauseContent;
    }

    public void setBeforeClauseContent(String beforeClauseContent) {
        this.beforeClauseContent = beforeClauseContent;
    }

    public String getBeforeClauseName() {
        return beforeClauseName;
    }

    public void setBeforeClauseName(String beforeClauseName) {
        this.beforeClauseName = beforeClauseName;
    }

}

==> ejc-proother-api-3.0.0-20220527.022952-99-sources.jar: com/ejianc/business/proother/vo/ChangeClauseVO.java <==
package com.ejianc.business.proother.vo;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;

/**
 * 分包变更条款
 * 
 * @author generator
 * 
 */
public class ChangeClauseVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    /**
     * 合同条款名称Id
     */
    private Long clauseNameId;

    /**
     * 合同条款名称
     */
    private String clauseName;

    /**
     * 合同条款内容
     */
    private String clauseContent;

    /**
     * 是否必填：1-是，0否
     */
    private Integer necessaryStatus;


    /**
     * 变更主键
     */
    private Long changeId;


    /**
     * 来源子表主键
     */
    private Long srcTblId;

    /**
     * 合同ID
     */
    private Long contractId;

    /**
     * 对比清单使用字段——原合同条款内容
     *
     */
    private String beforeClauseContent;

    /**
     * 对比清单使用字段——原合同条款名称
     *
     */
    private String beforeClauseName;

    /**
     * 对比清单使用字段——变更类型：0-新增项，1-删除项，2-条款内容便更
     */
    private Integer changeType;

    public Integer getChangeType() {
        return changeType;
    }

    public void setChangeType(Integer changeType) {
        this.changeType = changeType;
    }

    public Long getClauseNameId() {
        return clauseNameId;
    }

    @ReferDeserialTransfer
    public void setClauseNameId(Long clauseNameId) {
        this.clauseNameId = clauseNameId;
    }

    public String getClauseName() {
        return clauseName;
    }

    public void setClauseName(String clauseName) {
        this.clauseName = clauseName;
    }

    public String getClauseContent() {
        return clauseContent;
    }

    public void setClauseContent(String clauseContent) {
        this.clauseContent = clauseContent;
    }



    public Long getChangeId() {
        return changeId;
    }

    public void setChangeId(Long changeId) {
        this.changeId = changeId;
    }



    public Long getSrcTblId() {
        return srcTblId;
    }

    public void setSrcTblId(Long srcTblId) {
        this.srcTblId = srcTblId;
    }

    public Long getContractId() {
        return contractId;
    }

    public void setContractId(Long contractId) {
        this.contractId = contractId;
    }

    public String getBeforeClauseContent() {
        return beforeClauseContent;
    }

    public void setBeforeClauseContent(String beforeClauseContent) {
        this.beforeClauseContent = beforeClauseContent;
    }

    public String getBeforeClauseName() {
        return beforeClauseName;
    }

    public void setBeforeClauseName(String beforeClauseName) {
        this.beforeClauseName = beforeClauseName;
    }

    public Integer getNecessaryStatus() {
        return necessaryStatus;
    }

    public void setNecessaryStatus(Integer necessaryStatus) {
        this.necessaryStatus = necessaryStatus;
    }
}
